@@ -120,7 +120,9 @@ class Matcher(Preprocessor):
     all_matches_dict = {}
 
     for peptide in peptides:
-      print(peptide)
+
+      peptide = peptide.upper()
+
       if len(peptide) < self.split:
         continue
 
@@ -253,7 +255,9 @@ class Matcher(Preprocessor):
       rev_kmer_dict = {i: k for k, v in kmer_dict.items() for i in v}
 
     for peptide in peptides:
-      print(peptide)
+
+      peptide = peptide.upper()
+
       # record matches in a set so as to not duplicate matches
       matches = set()
 
@@ -390,7 +394,6 @@ class Matcher(Preprocessor):
             continue
 
       all_matches_dict[peptide] = list(matches)
-      print(list(matches))
 
     all_matches = []
 
